import { Component, ChangeDetectionStrategy, Input, HostListener, ChangeDetectorRef, EventEmitter } from '@angular/core';
import { DataTableComponent } from './data-table.component';
import { ForceUpdateReason } from './force-update-reason.model';
var DataTableRowComponent = (function () {
    function DataTableRowComponent(dt, changeDetectorRef) {
        this.dt = dt;
        this.changeDetectorRef = changeDetectorRef;
        this.forceUpdateEvent = new EventEmitter();
    }
    DataTableRowComponent.prototype.forceUpdate = function () {
        this.changeDetectorRef.markForCheck();
        this.forceUpdateEvent.emit(ForceUpdateReason.RowUpdate);
    };
    DataTableRowComponent.prototype.onRowClick = function ($event) {
        this.dt.onRowClick({ rowIndex: this.rowIndex, rowItem: this.rowItem, rowComponent: this });
    };
    DataTableRowComponent.prototype.onRowDBClick = function ($event) {
        this.dt.onRowDBClick({ rowIndex: this.rowIndex, rowItem: this.rowItem, rowComponent: this });
    };
    DataTableRowComponent.prototype.onRowCheckChange = function (rowIndex, rowItem) {
        this.dt.onRowCheckChange({ rowItem: rowItem, rowIndex: rowIndex, checked: rowItem.$$checked });
    };
    return DataTableRowComponent;
}());
export { DataTableRowComponent };
DataTableRowComponent.decorators = [
    { type: Component, args: [{
                selector: 're-data-table-row,[reDataTableRow]',
                template: "\n    <td *ngIf=\"checkable\" class=\"checkable-cell\">\n      <form class=\"form-inline\">\n        <div class=\"form-group\">\n          <div class=\"checkbox\">\n            <label>\n              <input type=\"checkbox\" name=\"rowChecker\" [(ngModel)]=\"rowItem.$checked\"\n                     (change)=\"onRowCheckChange(rowIndex, rowItem)\">\n            </label>\n          </div>\n        </div>\n      </form>\n    </td>\n    <ng-container *ngFor=\"let column of columns; let colIndex = index\">\n      <td reDataTableCell [dataTableTemplates]=\"dataTableTemplates\" [rowIndex]=\"rowIndex\" [colIndex]=\"colIndex\"\n          [column]=\"column\" [rowItem]=\"rowItem\" [style.width]=\"column.width || ''\" [editModel]=\"editModel\"\n          [isEditRow]=\"editRowItem == rowItem\">\n      </td>\n    </ng-container>\n  ",
                host: {
                    '[class.table-row-selected]': 'selectable && (rowItem == dt.selectedRowItem)',
                },
                changeDetection: ChangeDetectionStrategy.OnPush,
            },] },
];
/** @nocollapse */
DataTableRowComponent.ctorParameters = function () { return [
    { type: DataTableComponent, },
    { type: ChangeDetectorRef, },
]; };
DataTableRowComponent.propDecorators = {
    'checkable': [{ type: Input },],
    'rowItem': [{ type: Input },],
    'selectable': [{ type: Input },],
    'rowIndex': [{ type: Input },],
    'allChecked': [{ type: Input },],
    'columns': [{ type: Input },],
    'dataTableTemplates': [{ type: Input },],
    'editModel': [{ type: Input },],
    'editRowItem': [{ type: Input },],
    'onRowClick': [{ type: HostListener, args: ['click', ['$event'],] },],
    'onRowDBClick': [{ type: HostListener, args: ['dblclick', ['$event'],] },],
};
//# sourceMappingURL=data-table-row.component.js.map