import { Component, Input, ViewChild, Renderer2 } from '@angular/core';
import { TreeViewComponent } from './tree-view.component';
import { DraggableDirective } from '../draggable';
import { TreePanelComponent } from './tree-panel.component';
import { of } from 'rxjs/observable/of';
import 'rxjs/add/operator/map';
var TreeNodeComponent = (function () {
    function TreeNodeComponent(treeViewComponent, treePanelComponent, renderer) {
        this.treeViewComponent = treeViewComponent;
        this.treePanelComponent = treePanelComponent;
        this.renderer = renderer;
        this.checkable = false;
        this.lazyLoad = false;
        this.allowDraggable = false;
        this.allowMutipleSelected = false;
    }
    TreeNodeComponent.prototype.getNodeExpendIcon = function () {
        if (this.isLeaf()) {
            return this.leafIcon;
        }
        return this.node.$$expend ? this.expendIcon : this.collapseIcon;
    };
    TreeNodeComponent.prototype.onExpendedIconClick = function ($event) {
        var _this = this;
        $event.stopPropagation();
        if (this.isLeaf()) {
            return;
        }
        var loadObservable = of(null);
        if (this.lazyLoad && !this.node.$$loaded) {
            this.isLoading = true;
            loadObservable = this.loadChildren(this.node)
                .map(function (children) {
                _this.node.children = children || [];
                _this.node.$$loaded = true;
            });
        }
        loadObservable.subscribe(function () {
            _this.isLoading = false;
            _this.node.$$expend = !_this.node.$$expend;
            _this.treeViewComponent.onNodeItemExpended(_this.node);
        }, function () {
            _this.isLoading = false;
        });
    };
    TreeNodeComponent.prototype.onNodeItemClick = function ($event) {
        $event.stopPropagation();
        this.node.$$select = !this.node.$$select;
        this.treeViewComponent.onNodeItemClicked(this.node);
    };
    TreeNodeComponent.prototype.onNodeItemDbClicked = function () {
        this.treeViewComponent.onNodeItemDbClicked(this.node);
    };
    TreeNodeComponent.prototype.nodeItemCheckedChange = function (checked) {
        this.changeChildrenChecked(this.node.children, checked);
        this.treePanelComponent.onNodeItemCheckedChanged(this.node);
    };
    TreeNodeComponent.prototype.onChildrenNodeCheckedChange = function (node) {
        this.node.$$check = !this.node.children.some(function (item) { return !item.$$check; });
        this.treePanelComponent.onNodeItemCheckedChanged(node);
    };
    TreeNodeComponent.prototype.isLeaf = function () {
        if (this.lazyLoad && !this.node.$$loaded) {
            return false;
        }
        return !this.node.children || !this.node.children.length;
    };
    TreeNodeComponent.prototype.isAcceptDrop = function ($event) {
        var dropData = JSON.parse($event.dataTransfer.getData(DraggableDirective.DRAGGABLE_DATA_KEY));
        if (!dropData.data.node) {
            return false;
        }
        if (this.isNodeMyself(dropData)) {
            return false;
        }
        if (this.isDescendant(dropData.data.node, this.node)) {
            return false;
        }
        return true;
    };
    TreeNodeComponent.prototype.onDragEnter = function () {
        this.renderer.addClass(this.nodeItemContent.nativeElement, 'drop-node-enter');
    };
    TreeNodeComponent.prototype.onDragLeave = function () {
        var _this = this;
        setTimeout(function () {
            _this.renderer.removeClass(_this.nodeItemContent.nativeElement, 'drop-node-enter');
        });
    };
    TreeNodeComponent.prototype.onDropNodeItem = function ($event) {
        var _this = this;
        var dropData = JSON.parse($event.dataTransfer.getData(DraggableDirective.DRAGGABLE_DATA_KEY));
        if (dropData.data.node && !this.isNodeMyself(dropData)) {
            this.treeViewComponent.onNodeItemDroped({ target: this.node, data: dropData });
        }
        setTimeout(function () {
            _this.renderer.removeClass(_this.nodeItemContent.nativeElement, 'drop-node-enter');
        });
    };
    TreeNodeComponent.prototype.isNodeMyself = function (dropData) {
        return this.node[this.valueField] === dropData.data.node[this.valueField];
    };
    TreeNodeComponent.prototype.isDescendant = function (parent, target) {
        var _this = this;
        if (!parent) {
            return false;
        }
        return (parent.children || []).some(function (nodeItem) {
            return nodeItem[_this.valueField] === target[_this.valueField] || _this.isDescendant(nodeItem, target);
        });
    };
    TreeNodeComponent.prototype.changeChildrenChecked = function (nodes, checked) {
        var _this = this;
        if (!nodes) {
            return;
        }
        nodes.forEach(function (node) {
            node.$$check = checked;
            _this.changeChildrenChecked(node.children, checked);
        });
    };
    return TreeNodeComponent;
}());
export { TreeNodeComponent };
TreeNodeComponent.decorators = [
    { type: Component, args: [{
                selector: 're-tree-node,[reTreeNode]',
                template: "\n    <div class=\"node-item {{nodeCssClass}}\" reDraggable=\"re:node-item-drop\" [disabled]=\"!allowDraggable\"\n         [dragData]=\"{node: node, parent: parentNode}\">\n      <div class=\"node-item-panel\">\n        <i class=\"node-expend-icon {{getNodeExpendIcon()}}\"\n           (click)=\"onExpendedIconClick($event)\"></i>\n        <div class=\"node-item-content\" #nodeItemContent reDroppable=\"re:node-item-drop\" (onDrop)=\"onDropNodeItem($event)\"\n             (onDragEnter)=\"onDragEnter()\" (onDragLeave)=\"onDragLeave()\" [acceptDrop]=\"isAcceptDrop.bind(this)\">\n          <div class=\"node-check-box\">\n            <re-checkbox *ngIf=\"checkable\" [(ngModel)]=\"node.$check\" label=\"\"\n                         (valueChange)=\"nodeItemCheckedChange($event)\"></re-checkbox>\n          </div>\n          <ng-container *ngIf=\"!nodeItemTemplate\">\n          <span class=\"node-text\" [ngClass]=\"{'bg-primary': node.$select}\" (click)=\"onNodeItemClick($event)\"\n                (dblclick)=\"onNodeItemDbClicked($event)\">\n            <i *ngIf=\"iconField && node[iconField]\"\n               class=\"node-icon {{node[iconField]}}\"></i> {{node[textField] || ''}} <span\n            class=\"loading\" *ngIf=\"isLoading\">\n            <i class=\"{{loadingIcon}}\"></i></span>\n          </span>\n            <div class=\"toolbar\">\n              <ng-template *ngIf=\"nodeItemToolbarTemplate\" [ngTemplateOutlet]=\"nodeItemToolbarTemplate\"\n                           [ngOutletContext]=\"{$implicit: node, parentNode:parentNode, tree: this}\"></ng-template>\n            </div>\n          </ng-container>\n          <ng-container *ngIf=\"nodeItemTemplate\">\n            <ng-template *ngIf=\"nodeItemTemplate\" [ngTemplateOutlet]=\"nodeItemTemplate\"\n                         [ngOutletContext]=\"{$implicit: node,  parentNode:parentNode, tree: this }\"></ng-template>\n          </ng-container>\n        </div>\n      </div>\n      <re-tree-panel *ngIf=\"node.children && node.children.length && node.$expend\"\n                     class=\"children-view\"\n                     [treeData]=\"node.children\"\n                     [textField]=\"textField\"\n                     [valueField]=\"valueField\"\n                     [iconField]=\"iconField\"\n                     [checkable]=\"checkable\"\n                     [lazyLoad]=\"lazyLoad\"\n                     [loadingIcon]=\"loadingIcon\"\n                     [loadChildren]=\"loadChildren\"\n                     [allowDraggable]=\"allowDraggable && !isInDraggle\"\n                     [allowMutipleSelected]=\"allowMutipleSelected\"\n                     [parentNode]=\"node\"\n                     [nodeItemTemplate]=\"nodeItemTemplate\"\n                     [nodeItemToolbarTemplate]=\"nodeItemToolbarTemplate\"\n                     [leafIcon]=\"leafIcon\"\n                     [expendIcon]=\"expendIcon\"\n                     [collapseIcon]=\"collapseIcon\"\n                     (nodeItemCheckedChanged)=\"onChildrenNodeCheckedChange($event)\"\n      ></re-tree-panel>\n    </div>\n  ",
                styles: ["\n    .node-item{position:relative}.node-item-content /deep/ {display:inline-block}.node-item-content /deep/ .node-icon{margin-right:2px}.node-item-content /deep/ .node-text{cursor:pointer;padding:2px;border-radius:4px}.node-item-content /deep/ .node-text:not(.bg-primary):hover{border:1px dashed #ddd}.drop-node-enter{border:1px solid #2196f3}.toolbar,.node-check-box{display:inline-block}.expend-icon{cursor:pointer}.node-check-box .checkbox{margin:0px}.children-view{display:block;padding:10px 1.5rem;border-left:1px dashed #ddd;margin-left:5px}.children-view .node-item{position:relative}.children-view .node-item:before{content:' ';position:absolute;left:-1.5rem;border-top:1px dashed #ddd;display:inline-block;width:1.5rem;height:1px;top:10px}.loading{-webkit-animation:loadingAnimation 1.5s infinite alternate;-moz-animation:loadingAnimation 1.5s infinite alternate;-ms-animation:loadingAnimation 1.5s infinite alternate;-o-animation:loadingAnimation 1.5s infinite alternate;animation:loadingAnimation 1.5s infinite alternate}@-webkit-keyframes loadingAnimation{50%{color:#FF9800}100%{color:#4CAF50}}\n  "],
                exportAs: 'treeNode'
            },] },
];
/** @nocollapse */
TreeNodeComponent.ctorParameters = function () { return [
    { type: TreeViewComponent, },
    { type: TreePanelComponent, },
    { type: Renderer2, },
]; };
TreeNodeComponent.propDecorators = {
    'node': [{ type: Input },],
    'parentNode': [{ type: Input },],
    'valueField': [{ type: Input },],
    'textField': [{ type: Input },],
    'nodeCssClass': [{ type: Input },],
    'iconField': [{ type: Input },],
    'checkable': [{ type: Input },],
    'lazyLoad': [{ type: Input },],
    'loadingIcon': [{ type: Input },],
    'loadChildren': [{ type: Input },],
    'allowDraggable': [{ type: Input },],
    'allowMutipleSelected': [{ type: Input },],
    'nodeItemTemplate': [{ type: Input },],
    'nodeItemToolbarTemplate': [{ type: Input },],
    'leafIcon': [{ type: Input },],
    'expendIcon': [{ type: Input },],
    'collapseIcon': [{ type: Input },],
    'nodeItemContent': [{ type: ViewChild, args: ['nodeItemContent',] },],
};
//# sourceMappingURL=tree-node.component.js.map